/******************************************************************************/
/*  xxapvdrp.p   Vendor Activity Report                                       */
/****************************************************************************&*/

{mfdtitle.i "a00"}

define variable vend    like ap_vend.
define variable vend1   like ap_vend.
define variable apdate  like ap_date.
define variable apdate1 like ap_date.
define variable name    like ad_name.
define variable type    like ap_type format "X(4)".
define variable summary like mfc_logical format "Summary/Detail"  label "Summary/Detail".
define variable min_1099_amt as decimal label "Minimum 1099 Amount".
define variable pass as integer.
define variable vdtype like vd_type label "Supplier Type".
define variable vdtype1 like vdtype.
define variable vd1099_only  like mfc_logical  label "Include 1099 Suppliers Only" initial yes no-undo.
def var msg1 as char.

define variable base_ckd_amt like ckd_amt no-undo.
define variable base_ck_amt like ckd_amt no-undo.
define variable curr_ck_amt like ckd_amt no-undo.
define variable base_vend_amt like ckd_amt no-undo.
define variable tax_id like vd_tax_id no-undo.
define variable mc-error-number like msg_nbr no-undo.
define variable l_addr as character format "x(38)".
define buffer apmstr for ap_mstr.
define variable entity         like en_entity.
define variable entity1        like en_entity.



form
   skip
		"*       =============    Suppliers Spending Report     ==========            *" skip
		"*         Calculates the total amount spent by the supplier                  *" skip
		"*         during the period of time (based on checks issued).                *" skip
    "*         Amounts are in Base Currency, using Transaction Exchange Rate      *" skip(1)
   vend Colon 15
   vend1          label {t001.i} colon 49 skip
   apdate         Colon 15
   apdate1        label {t001.i} colon 49 skip
   entity         Colon 15
   entity1        label {t001.i} colon 49 skip (1)
 with frame a side-labels width 80.

find first gl_ctrl
      where gl_ctrl.gl_domain = global_domain  no-lock no-error.

repeat:

   if vend1   = hi_char then vend1   = "".
   if entity1 = hi_char then entity1 = "".
   if apdate = low_date then apdate = ?.
   if apdate1 = hi_date then apdate1 = ?.


   update
    vend vend1
    apdate apdate1
    entity entity1
    with frame a.

   bcdparm = "".
   {mfquoter.i vend   }
   {mfquoter.i vend1  }
   {mfquoter.i apdate }
   {mfquoter.i apdate1}
   {mfquoter.i entity   }
   {mfquoter.i entity1  }

   if vend1   = "" then vend1 = hi_char.
   if entity1 = "" then entity1 = hi_char.
   if apdate  = ? then apdate = low_date.
   if apdate1 = ? then apdate1 = hi_date.

   /* OUTPUT DESTINATION SELECTION */
   {gpselout.i &printType = "printer"
               &printWidth = 132
               &pagedFlag = " "
               &stream = " "
               &appendToFile = " "
               &streamedOutputToTerminal = " "
               &withBatchOption = "yes"
               &displayStatementType = 1
               &withCancelMessage = "yes"
               &pageBottomMargin = 6
               &withEmail = "yes"
               &withWinprint = "yes"
               &defineVariables = "yes"}
   {mfphead.i}

  aploop:
  for each ap_mstr no-lock
     where ap_domain = global_domain
     and   ap_vend >= vend    and ap_vend <= vend1
     and   ap_date >= apdate  and (ap_date <= apdate1)
     and (ap_type = "CK")
     break by ap_vend:

    if first-of (ap_vend) then do:
       base_vend_amt = 0 .
    end.

    for first ck_mstr
    fields( ck_domain ck_bank ck_clr_date ck_cmtindx ck_curr
            ck_exru_seq ck_ex_rate ck_ex_rate2
            ck_ex_ratetype ck_nbr ck_ref ck_status
            ck_type ck_voiddate ck_voideff)
    no-lock
     where ck_mstr.ck_domain = global_domain and  ck_ref = ap_ref: end.

    if ck_status <> "VOID" then do:

       assign
          base_ck_amt = 0
          curr_ck_amt = 0.

       for each ckd_det  where ckd_det.ckd_domain = global_domain and
         ckd_ref = ap_ref no-lock:
           /*only find checks for vouchers
             with entities within selected range */
           find apmstr  where apmstr.ap_domain = global_domain and
           apmstr.ap_type = "VO" and apmstr.ap_ref
           = ckd_voucher no-lock no-error.
           if not available apmstr then next aploop.
           if available apmstr and
           (apmstr.ap_entity < entity or apmstr.ap_entity > entity1)
           then next aploop.

          /* IF NECESSARY, DO EXCHANGE CONVERSION */
          base_ckd_amt = ckd_amt.

          if base_curr <> ck_curr and base_ckd_amt <> 0
          then do:

             /* THE BELOW CONDITION WILL BE TRUE ONLY AFTER */
             /* BCC FOR FOREIGN CURRENCY VOUCHERS PAID IN   */
             /* BASE CURRENCY BEFORE BCC.                   */

             if  ckd_voucher <> ""
             and can-find (first ap_mstr
                               where ap_mstr.ap_domain = global_domain and
                                ap_type =  "VO"
                                and ap_ref  =  ckd_voucher
                                and ap_curr <> ck_curr)
             then
                base_ckd_amt = ckd_cur_amt.
             /* CONVERT FROM FOREIGN TO BASE CURRENCY */
             {gprunp.i "mcpl" "p" "mc-curr-conv"
                "(input ck_curr,
                  input base_curr,
                  input ck_ex_rate,
                  input ck_ex_rate2,
                  input base_ckd_amt,
                  input true, /* ROUND */
                  output base_ckd_amt,
                  output mc-error-number)"}.
             if mc-error-number <> 0 then do:
                {pxmsg.i &MSGNUM=mc-error-number &ERRORLEVEL=2}
             end.
          end.

          assign
             base_ck_amt = base_ck_amt + base_ckd_amt
             curr_ck_amt = curr_ck_amt + ckd_amt
             base_vend_amt = base_vend_amt + base_ckd_amt.

       end. /* FOR EACH CKD_DET */
    end. /*if ck_status <> "VOID" then do:*/


    if last-of (ap_vend) then do:
      for first ad_mstr where ad_domain = global_domain
        and ad_addr = ap_vend no-lock: end.
      disp
        ap_vend
        ad_name when avail ad_mstr
        base_vend_amt
        base_curr
        with width 80.
    end.

  end.

  {mfrtrail.i}
end .